Learn R Programming

cookies (version 0.2.3)

.http_date: Convert expiration days to the expected date format

Description

Convert expiration days to the expected date format

Usage

.http_date(expiration)

Value

A string of the date in the required format.

Arguments

expiration

Days after which the cookie should expire. To remove an HttpOnly cookie, send a negative value for this attribute.