Learn R Programming

cookies (version 0.2.3)

.validate_domain: Ensure domain is valid

Description

Ensure domain is valid

Usage

.validate_domain(domain)

Value

NULL or domain as a character.

Arguments

domain

The host to which the cookie will be sent (including subdomains). If this is NULL (default) the cookie will only be sent to the host of the page where this cookie was set (not including subdomains).