add_cookie_handlers: Add cookies to an existing shiny ui
Description
Wrap a shiny ui in this function in order to add cookie-handling
functionality. The ui can be defined in any format compatible with shiny,
using functions such as shiny::fluidPage(), shiny::bootstrapPage(),
shiny::htmlTemplate(), or a raw HTML string.
Usage
add_cookie_handlers(ui)
Value
An object with the same signature as the input ui, but with the
dependencies needed to handle cookies. If ui is a shiny::tagList(), a
shiny::tagList() will be returned; if ui is a function, a function will
be returned.
Arguments
ui
A 0- or 1-argument function defining the ui of a shiny app, or a
shiny::tagList().