powered by
Convert expiration days to the expected date format
.http_date(expiration)
A string of the date in the required format.
Days after which the cookie should expire. To remove an HttpOnly cookie, send a negative value for this attribute.